@@ -2,7 +2,7 @@ package Test2::API::Stack;
 use strict;
 use warnings;
 
-our $VERSION = '1.302140';
+our $VERSION = '1.302166';
 
 
 use Test2::Hub();
@@ -63,6 +63,12 @@ sub all {
     return @$self;
 }
 
+sub root {
+    my $self = shift;
+    return unless @$self;
+    return $self->[0];
+}
+
 sub clear {
     my $self = shift;
     @$self = ();
@@ -210,7 +216,7 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2019 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
